==> ejc-proequipmentcorp-impl-3.0.0-20221124.024157-181-sources.jar: com/ejianc/business/proequipmentcorppur/purchaseApply/bean/PurchaseApplyDetailedEntity.java <==
package com.ejianc.business.proequipmentcorppur.purchaseApply.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 采购申请-计划清单表
 *
 * @author generator
 *
 */
@TableName("ejc_proequipmentcorp_purchase_apply_detailed")
public class PurchaseApplyDetailedEntity extends BaseEntity {

    private static final long serialVersionUID = -7018484654437355028L;

    @TableField(value="code")
    private String code; // 序号
    @TableField(value="equipment_type")
    private String equipmentType; // 设备类别
    @TableField(value="equipment_name")
    private String equipmentName; // 设备名称
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="company")
    private String company; // 单位
    @TableField(value="plan_num")
    private Long planNum; // 计划数量
    @TableField(value="estimate_price")
    private BigDecimal estimatePrice; // 预计单价
    @TableField(value="estimate_amount")
    private BigDecimal estimateAmount; // 预计金额
    @TableField(value="estimate_purchase_date")
    private Date estimatePurchaseDate; // 预计购置时间
    @TableField(value="manufacturer")
    private String manufacturer; // 生产厂家
    @TableField(value="detail_memo")
    private String detailMemo; // 备注
    @TableField(value="source_type")
    private String sourceType; // 来源类型
    @TableField(value="apply_id")
    private Long applyId; // 所属申请Id(计划表主键相当于pid)
    @TableField(value="doc_category_id")
    private Long docCategoryId; // 档案分类id
    @TableField(value="doc_id")
    private Long docId; // 档案Id
    @TableField(value="tid")
    private Long tid; // 上级id
    @TableField(value="parent_id")
    private Long parentId; // 父类id
    @TableField(value="leaf_flag")
    private Boolean leafFlag; //
    @TableField(value="equipment_code")
    private String equipmentCode; // 设备编码

    @TableField(value = "remaining_num")
    private Long remainingNum; //剩余可申请数量
    @TableField(value = "applied_num")
    private Long appliedNum; //已申请数量
    @TableField(value = "source_plan_id")
    private Long sourcePlanId; // 来源计划主表Id
    @TableField(value = "source_id")
    private Long sourceId; //来源业务单据Id


    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getEquipmentType() {
        return equipmentType;
    }

    public void setEquipmentType(String equipmentType) {
        this.equipmentType = equipmentType;
    }
    public String getEquipmentName() {
        return equipmentName;
    }

    public void setEquipmentName(String equipmentName) {
        this.equipmentName = equipmentName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getCompany() {
        return company;
    }

    public void setCompany(String company) {
        this.company = company;
    }
    public Long getPlanNum() {
        return planNum;
    }

    public void setPlanNum(Long planNum) {
        this.planNum = planNum;
    }
    public BigDecimal getEstimatePrice() {
        return estimatePrice;
    }

    public void setEstimatePrice(BigDecimal estimatePrice) {
        this.estimatePrice = estimatePrice;
    }
    public BigDecimal getEstimateAmount() {
        return estimateAmount;
    }

    public void setEstimateAmount(BigDecimal estimateAmount) {
        this.estimateAmount = estimateAmount;
    }
    public Date getEstimatePurchaseDate() {
        return estimatePurchaseDate;
    }

    public void setEstimatePurchaseDate(Date estimatePurchaseDate) {
        this.estimatePurchaseDate = estimatePurchaseDate;
    }
    public String getManufacturer() {
        return manufacturer;
    }

    public void setManufacturer(String manufacturer) {
        this.manufacturer = manufacturer;
    }
    public String getDetailMemo() {
        return detailMemo;
    }

    public void setDetailMemo(String detailMemo) {
        this.detailMemo = detailMemo;
    }
    public String getSourceType() {
        return sourceType;
    }

    public void setSourceType(String sourceType) {
        this.sourceType = sourceType;
    }
    public Long getDocCategoryId() {
        return docCategoryId;
    }

    public void setDocCategoryId(Long docCategoryId) {
        this.docCategoryId = docCategoryId;
    }
    public Long getDocId() {
        return docId;
    }

    public void setDocId(Long docId) {
        this.docId = docId;
    }
    public Long getTid() {
        return tid;
    }

    public void setTid(Long tid) {
        this.tid = tid;
    }
    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }
    public Boolean getLeafFlag() {
        return leafFlag;
    }

    public void setLeafFlag(Boolean leafFlag) {
        this.leafFlag = leafFlag;
    }

    public String getEquipmentCode() {
        return equipmentCode;
    }

    public void setEquipmentCode(String equipmentCode) {
        this.equipmentCode = equipmentCode;
    }

    public Long getApplyId() {
        return applyId;
    }

    public void setApplyId(Long applyId) {
        this.applyId = applyId;
    }

    public Long getSourcePlanId() {
        return sourcePlanId;
    }

    public void setSourcePlanId(Long sourcePlanId) {
        this.sourcePlanId = sourcePlanId;
    }

    public Long getAppliedNum() {
        return appliedNum;
    }

    public void setAppliedNum(Long appliedNum) {
        this.appliedNum = appliedNum;
    }

    public Long getRemainingNum() {
        return remainingNum;
    }

    public void setRemainingNum(Long remainingNum) {
        this.remainingNum = remainingNum;
    }

    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
}

==> ejc-proequipmentcorp-impl-3.0.0-20250828.105809-512-sources.jar: com/ejianc/business/proequipmentcorppur/purchaseApply/bean/PurchaseApplyDetailedEntity.java <==
package com.ejianc.business.proequipmentcorppur.purchaseApply.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 采购申请-计划清单表
 *
 * @author generator
 *
 */
@TableName("ejc_proequipmentcorp_purchase_apply_detailed")
public class PurchaseApplyDetailedEntity extends BaseEntity {

    private static final long serialVersionUID = -7018484654437355028L;

    @TableField(value="code")
    private String code; // 序号
    @TableField(value="equipment_type")
    private String equipmentType; // 设备类别
    @TableField(value="equipment_name")
    private String equipmentName; // 设备名称
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="company")
    private String company; // 单位
    @TableField(value="plan_num")
    private Long planNum; // 计划数量
    @TableField(value="estimate_price")
    private BigDecimal estimatePrice; // 预计单价
    @TableField(value="estimate_amount")
    private BigDecimal estimateAmount; // 预计金额
    @TableField(value="estimate_purchase_date")
    private Date estimatePurchaseDate; // 预计购置时间
    @TableField(value="manufacturer")
    private String manufacturer; // 生产厂家
    @TableField(value="detail_memo")
    private String detailMemo; // 备注
    @TableField(value="source_type")
    private String sourceType; // 来源类型
    @TableField(value="apply_id")
    private Long applyId; // 所属申请Id(计划表主键相当于pid)
    @TableField(value="doc_category_id")
    private Long docCategoryId; // 档案分类id
    @TableField(value="doc_id")
    private Long docId; // 档案Id
    @TableField(value="tid")
    private Long tid; // 上级id
    @TableField(value="parent_id")
    private Long parentId; // 父类id
    @TableField(value="leaf_flag")
    private Boolean leafFlag; //
    @TableField(value="equipment_code")
    private String equipmentCode; // 设备编码

    @TableField(value = "remaining_num")
    private Long remainingNum; //剩余可申请数量
    @TableField(value = "applied_num")
    private Long appliedNum; //已申请数量
    @TableField(value = "source_plan_id")
    private Long sourcePlanId; // 来源计划主表Id
    @TableField(value = "source_id")
    private Long sourceId; //来源业务单据Id

    @TableField(value="history_price_area")
    private String historyPriceArea;//历史价格区间（无税）
    @TableField(value="history_tax_price_area")
    private String historyTaxPriceArea;//历史价格区间（含税）
    @TableField(value="guide_price_area")
    private String guidePriceArea; // 公司指导价区间（无税）
    @TableField(value="guide_tax_price_area")
    private String guideTaxPriceArea; // 公司指导价区间（含税）
    @TableField(value="detail_measurement_rules")
    private String detailMeasurementRules;//计量规则

    @TableField(value="job_content")
    private String jobContent;//工作内容

    public String getDetailMeasurementRules() {
        return detailMeasurementRules;
    }

    public void setDetailMeasurementRules(String detailMeasurementRules) {
        this.detailMeasurementRules = detailMeasurementRules;
    }

    public String getJobContent() {
        return jobContent;
    }

    public void setJobContent(String jobContent) {
        this.jobContent = jobContent;
    }
    public String getHistoryPriceArea() {
        return historyPriceArea;
    }

    public void setHistoryPriceArea(String historyPriceArea) {
        this.historyPriceArea = historyPriceArea;
    }

    public String getHistoryTaxPriceArea() {
        return historyTaxPriceArea;
    }

    public void setHistoryTaxPriceArea(String historyTaxPriceArea) {
        this.historyTaxPriceArea = historyTaxPriceArea;
    }

    public String getGuidePriceArea() {
        return guidePriceArea;
    }

    public void setGuidePriceArea(String guidePriceArea) {
        this.guidePriceArea = guidePriceArea;
    }

    public String getGuideTaxPriceArea() {
        return guideTaxPriceArea;
    }

    public void setGuideTaxPriceArea(String guideTaxPriceArea) {
        this.guideTaxPriceArea = guideTaxPriceArea;
    }



    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getEquipmentType() {
        return equipmentType;
    }

    public void setEquipmentType(String equipmentType) {
        this.equipmentType = equipmentType;
    }
    public String getEquipmentName() {
        return equipmentName;
    }

    public void setEquipmentName(String equipmentName) {
        this.equipmentName = equipmentName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getCompany() {
        return company;
    }

    public void setCompany(String company) {
        this.company = company;
    }
    public Long getPlanNum() {
        return planNum;
    }

    public void setPlanNum(Long planNum) {
        this.planNum = planNum;
    }
    public BigDecimal getEstimatePrice() {
        return estimatePrice;
    }

    public void setEstimatePrice(BigDecimal estimatePrice) {
        this.estimatePrice = estimatePrice;
    }
    public BigDecimal getEstimateAmount() {
        return estimateAmount;
    }

    public void setEstimateAmount(BigDecimal estimateAmount) {
        this.estimateAmount = estimateAmount;
    }
    public Date getEstimatePurchaseDate() {
        return estimatePurchaseDate;
    }

    public void setEstimatePurchaseDate(Date estimatePurchaseDate) {
        this.estimatePurchaseDate = estimatePurchaseDate;
    }
    public String getManufacturer() {
        return manufacturer;
    }

    public void setManufacturer(String manufacturer) {
        this.manufacturer = manufacturer;
    }
    public String getDetailMemo() {
        return detailMemo;
    }

    public void setDetailMemo(String detailMemo) {
        this.detailMemo = detailMemo;
    }
    public String getSourceType() {
        return sourceType;
    }

    public void setSourceType(String sourceType) {
        this.sourceType = sourceType;
    }
    public Long getDocCategoryId() {
        return docCategoryId;
    }

    public void setDocCategoryId(Long docCategoryId) {
        this.docCategoryId = docCategoryId;
    }
    public Long getDocId() {
        return docId;
    }

    public void setDocId(Long docId) {
        this.docId = docId;
    }
    public Long getTid() {
        return tid;
    }

    public void setTid(Long tid) {
        this.tid = tid;
    }
    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }
    public Boolean getLeafFlag() {
        return leafFlag;
    }

    public void setLeafFlag(Boolean leafFlag) {
        this.leafFlag = leafFlag;
    }

    public String getEquipmentCode() {
        return equipmentCode;
    }

    public void setEquipmentCode(String equipmentCode) {
        this.equipmentCode = equipmentCode;
    }

    public Long getApplyId() {
        return applyId;
    }

    public void setApplyId(Long applyId) {
        this.applyId = applyId;
    }

    public Long getSourcePlanId() {
        return sourcePlanId;
    }

    public void setSourcePlanId(Long sourcePlanId) {
        this.sourcePlanId = sourcePlanId;
    }

    public Long getAppliedNum() {
        return appliedNum;
    }

    public void setAppliedNum(Long appliedNum) {
        this.appliedNum = appliedNum;
    }

    public Long getRemainingNum() {
        return remainingNum;
    }

    public void setRemainingNum(Long remainingNum) {
        this.remainingNum = remainingNum;
    }

    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
}
